pub unsafe fn hexdump8_very_ex_raw<W: Write>(
writer: &mut W,
ptr: *const u8,
len: usize,
disp_addr: u64,
) -> ResultExpand description
Do a hex dump against a writer, formatting data as individual 8-bit bytes alongside an 8-bit ASCII panel, displaying up to 16 bytes per line, using suspect raw pointers.
Safety
The caller must ensure that the memory range [ptr, ptr + len) is mapped and readable.
KASan instrumentation is bypassed during pointer accesses to prevent panic loops.